# my_function: just prints hello
def my_function():
    print("Hello from my_function!")


def another_function():
    print("hello from another_function!")


if __name__ == '__main__':
    """ This runs when you execute '$ python3 gister/gister.py' """
    my_function()
